@@ -27,7 +27,7 @@ var (
 // If shouldExist is true, the function will try to select either "main" or the parent
 // directory name, depending on which one is there.
 func (e *Editor) exeName(sourceFilename string, shouldExist bool) string {
-	const exeFirstName = "main" // The default name
+	exeFirstName := "main" // The default name
 	sourceDir := filepath.Dir(sourceFilename)
 
 	// NOTE: Abs is used to prevent sourceDirectoryName from becoming just "."
@@ -43,6 +43,11 @@ func (e *Editor) exeName(sourceFilename string, shouldExist bool) string {
 		if files.IsFile(filepath.Join(sourceDir, exeFirstName)) {
 			return exeFirstName
 		}
+		// If the name of the source file, without the extension, exists, use that
+		exeFirstName = strings.TrimSuffix(filepath.Base(sourceFilename), filepath.Ext(sourceFilename))
+		if files.IsFile(filepath.Join(sourceDir, exeFirstName)) {
+			return exeFirstName
+		}
 		// Use the name of the source directory as the default executable filename instead
 		if files.IsFile(filepath.Join(sourceDir, sourceDirectoryName)) {
 			// exeFirstName = sourceDirectoryName
@@ -477,7 +482,12 @@ func (e *Editor) GenerateBuildCommand(c *vt100.Canvas, tty *vt100.TTY, filename
 		cmd.Dir = sourceDir
 		return cmd, everythingIsFine, nil
 	case mode.Odin:
-		cmd = exec.Command("odin", "build", ".") // using the filename and then "-file" instead of "." is also possible
+		pattern := filepath.Join(sourceDir, "*.odin")
+		if matches, err := filepath.Glob(pattern); err == nil && len(matches) != 1 {
+			cmd = exec.Command("odin", "build", ".", "-max-error-count:1")
+		} else {
+			cmd = exec.Command("odin", "build", sourceFilename, "-file", "-build-mode:exe", "-max-error-count:1")
+		}
 		cmd.Dir = sourceDir
 		return cmd, everythingIsFine, nil
 	case mode.CS:
@@ -890,7 +900,7 @@ func (e *Editor) BuildOrExport(c *vt100.Canvas, tty *vt100.TTY, status *StatusBa
 					lineNumberString := locCol[0]
 					lineColumnString := locCol[1]
 
-					const subtractOne = false
+					const subtractOne = true
 					e.MoveToIndex(c, status, lineNumberString, lineColumnString, subtractOne)
 
 					// Return the error message
