@@ -11,6 +11,7 @@ import (
 	"time"
 
 	"github.com/xyproto/clip"
+	"github.com/xyproto/files"
 	"github.com/xyproto/mode"
 	"github.com/xyproto/vt100"
 )
@@ -123,6 +124,7 @@ func (e *Editor) CommandToFunction(c *vt100.Canvas, tty *vt100.TTY, status *Stat
 		inserttime
 		insertdateandtime
 		quit
+		runmake
 		save
 		savequit
 		savequitclear
@@ -293,6 +295,22 @@ func (e *Editor) CommandToFunction(c *vt100.Canvas, tty *vt100.TTY, status *Stat
 			e.InsertString(c, dateString+" "+timeString)
 			e.addSpace = true
 		},
+		runmake: func() {
+			workDir := filepath.Dir(e.filename)
+			found := false
+			for _, fn := range []string{"GNUmakefile", "makefile", "Makefile"} {
+				if files.Exists(filepath.Join(workDir, fn)) {
+					found = true
+					break
+				}
+			}
+			if found {
+				e.UserSave(c, tty, status)
+				quitExecShellCommand(tty, workDir, "make")
+			} else {
+				status.SetErrorMessageAfterRedraw("no Makefile")
+			}
+		},
 		save: func() { // save the current file
 			e.UserSave(c, tty, status)
 		},
@@ -368,6 +386,8 @@ func (e *Editor) CommandToFunction(c *vt100.Canvas, tty *vt100.TTY, status *Stat
 		functionID = inserttime
 	case "insertdateandtime", "dateandtime", "dt", "dati", "datim":
 		functionID = insertdateandtime
+	case "make":
+		functionID = runmake
 	case "qs", "byes", "cus", "exitsave", "quitandsave", "quitsave", "qw", "saq", "saveandquit", "saveexit", "saveq", "savequit", "savq", "sq", "wq", "↑", "c:23": // ctrl-w, if the user keeps holding down ctrl
 		functionID = savequit
 	case "s", "sa", "sav", "save", "w", "ww", "↓", "c:19": // ctrl-s, if the user keeps holding down ctrl
