@@ -15,7 +15,7 @@ func (e *Editor) FuncPrefix() string {
 	switch e.mode {
 	case mode.Clojure:
 		return "defn "
-	case mode.Crystal, mode.Nim, mode.Mojo, mode.Python, mode.Scala:
+	case mode.Crystal, mode.Nim, mode.Mojo, mode.Python, mode.Scala, mode.Starlark:
 		return "def "
 	case mode.GDScript, mode.Go:
 		return "func "
@@ -48,7 +48,7 @@ func (e *Editor) LooksLikeFunctionDef(line, funcPrefix string) bool {
 	switch e.mode {
 	// Very unscientific and approximate function definition detection for C and C++
 	// TODO: Write a C parser and a C++ parser...
-	case mode.C, mode.Cpp:
+	case mode.Arduino, mode.C, mode.Cpp, mode.D, mode.Dart, mode.Hare, mode.Jakt, mode.Java, mode.JavaScript, mode.Kotlin, mode.ObjC, mode.Scala, mode.Shader, mode.TypeScript, mode.Zig:
 		if strings.HasSuffix(trimmedLine, "()") {
 			return true
 		}
@@ -74,6 +74,11 @@ func (e *Editor) LooksLikeFunctionDef(line, funcPrefix string) bool {
 			}
 		}
 		fallthrough
+	case mode.Odin:
+		if strings.Contains(trimmedLine, " :: proc(") {
+			return true
+		}
+		fallthrough
 	default:
 		if strings.Contains(trimmedLine, "(") {
 			fields := strings.SplitN(trimmedLine, "(", 2)
@@ -98,6 +103,15 @@ func (e *Editor) LooksLikeFunctionDef(line, funcPrefix string) bool {
 
 // FunctionName tries to extract the function name given a line with what looks like a function definition.
 func (e *Editor) FunctionName(line string) string {
+	if e.mode == mode.Odin {
+		if strings.Contains(line, " :: proc(") {
+			fields := strings.SplitN(line, " :: proc(", 2)
+			name := strings.TrimSpace(fields[0])
+			if name != "" {
+				return name
+			}
+		}
+	}
 	var s string
 	funcPrefix := e.FuncPrefix()
 	if e.LooksLikeFunctionDef(line, funcPrefix) {
