@@ -1451,7 +1451,7 @@ func Loop(tty *vt100.TTY, fnord FilenameOrData, lineNumber LineNumber, colNumber
 			// * the rune to the left is not a blank character or the line ends with {, (, [ or :
 			// * and also if it the cursor is not to the very left
 			// * and also if this is not a text file or a blank file
-			noSmartIndentation := e.mode == mode.GoAssembly || e.mode == mode.Perl || e.mode == mode.Assembly || e.mode == mode.OCaml || e.mode == mode.StandardML || e.mode == mode.Blank
+			noSmartIndentation := e.NoSmartIndentation()
 			if (!unicode.IsSpace(leftRune) || endsWithSpecial) && e.pos.sx > 0 && !noSmartIndentation {
 				lineAbove := 1
 				if strings.TrimSpace(e.Line(LineIndex(y-lineAbove))) == "" {
@@ -1669,9 +1669,11 @@ func Loop(tty *vt100.TTY, fnord FilenameOrData, lineNumber LineNumber, colNumber
 			oldLineIndex := e.LineIndex()
 
 			// func prefix must exist for this language/mode for GoToDefinition to be supported
-			jumpedToDefinition := e.FuncPrefix() != "" && e.GoToDefinition(tty, c, status)
-			if jumpedToDefinition {
-				break
+			if e.ProgrammingLanguage() {
+				jumpedToDefinition := e.FuncPrefix() != "" && e.GoToDefinition(tty, c, status)
+				if jumpedToDefinition {
+					break
+				}
 			}
 
 			// TODO: Is this correct? Should it only happen if jumpedToDefinition is true? false?
@@ -1931,9 +1933,9 @@ func Loop(tty *vt100.TTY, fnord FilenameOrData, lineNumber LineNumber, colNumber
 			}
 
 			// Deal with the portal
-			status.Clear(c, false)
+			status.ClearAll(c, false)
 			if HasPortal() {
-				status.SetMessage("Closing portal")
+				status.SetMessageAfterRedraw("Closing portal")
 				e.ClosePortal()
 			} else {
 				portal, err := e.NewPortal()
@@ -1951,9 +1953,8 @@ func Loop(tty *vt100.TTY, fnord FilenameOrData, lineNumber LineNumber, colNumber
 					status.Show(c, e)
 					break
 				}
-				status.SetMessage("Opening a portal at " + portal.String())
+				status.SetMessageAfterRedraw("Opening a portal at " + portal.String())
 			}
-			status.Show(c, e)
 		case "c:2": // ctrl-b, go back after jumping to a definition, bookmark, unbookmark or jump to bookmark. Toggle breakpoint if in debug mode.
 
 			if e.nanoMode.Load() { // nano: ctrl-b, cursor forward
@@ -1961,7 +1962,7 @@ func Loop(tty *vt100.TTY, fnord FilenameOrData, lineNumber LineNumber, colNumber
 				break
 			}
 
-			status.Clear(c, false)
+			status.ClearAll(c, false)
 
 			// Check if we have jumped to a definition and need to go back
 			if len(backFunctions) > 0 {
@@ -2011,7 +2012,7 @@ func Loop(tty *vt100.TTY, fnord FilenameOrData, lineNumber LineNumber, colNumber
 					bookmark = e.pos.Copy()
 					// TODO: Modify the statusbar implementation so that extra spaces are not needed here.
 					s := "Bookmarked line " + e.LineNumber().String()
-					status.SetMessage("  " + s + "  ")
+					status.SetMessageAfterRedraw("  " + s + "  ")
 				} else if bookmark.LineNumber() == e.LineNumber() {
 					// bookmarking the same line twice: remove the bookmark
 					s := "Removed bookmark for line " + bookmark.LineNumber().String()
