@@ -22,7 +22,7 @@ import (
 )
 
 const (
-	versionString = "Orbiton 2.68.2"
+	versionString = "Orbiton 2.68.3"
 
 	// How many lines of context above and below should the tab completion try to use?
 	ollamaContextLines = 20
@@ -70,6 +70,8 @@ func main() {
 		versionFlag            bool
 		nanoMode               bool
 		ollamaTabCompletion    bool
+		catFlag                bool
+		batFlag                bool
 	)
 
 	pflag.BoolVarP(&copyFlag, "copy", "c", false, "copy a file into the clipboard and quit")
@@ -84,8 +86,10 @@ func main() {
 	pflag.BoolVarP(&createDirectoriesFlag, "create-dir", "d", false, "create diretories when opening a new file")
 	pflag.BoolVarP(&versionFlag, "version", "v", false, "version information")
 	pflag.StringVarP(&inputFileWhenRunning, "input-file", "i", "input.txt", "input file when building and running programs")
-	pflag.BoolVarP(&nanoMode, "nano", "e", false, "Nano/Pico mode")
-	pflag.BoolVarP(&ollamaTabCompletion, "ollama", "o", false, "use Ollama for tab completion")
+	pflag.BoolVarP(&nanoMode, "nano", "a", false, "Nano/Pico mode")
+	pflag.BoolVarP(&ollamaTabCompletion, "ollama", "o", env.Bool("ORBITON_OLLAMA"), "use Ollama for tab completion")
+	pflag.BoolVarP(&catFlag, "list", "t", false, "List the file with colors instead of editing it")
+	pflag.BoolVarP(&batFlag, "bat", "b", false, "Cat the file with colors instead of editing it, using bat")
 
 	pflag.Parse()
 
@@ -172,11 +176,19 @@ func main() {
 		if filepath.Ext(filename) == ".sh" || files.BinDirectory(filename) || strings.HasPrefix(headString, "#!") {
 			os.Chmod(filename, 0o755)
 		}
-		if tailString != "" {
+		if tailString != "" && !batFlag {
 			fmt.Printf("Wrote %d bytes to %s from the clipboard. Tail bytes: %s\n", n, filename, strings.TrimSpace(strings.ReplaceAll(tailString, "\n", "\\n")))
 		} else {
 			fmt.Printf("Wrote %d bytes to %s from the clipboard.\n", n, filename)
 		}
+		if catFlag {
+			// List the file in a colorful way and quit
+			quitCat(&FilenameOrData{filename, []byte{}, 0, false})
+		} else if batFlag {
+			// List the file in a colorful way, using bat, and quit
+			quitBat(filename)
+		}
+
 		return
 	}
 
@@ -199,11 +211,22 @@ func main() {
 		if n == 1 {
 			plural = ""
 		}
-		if tailString != "" {
+		if !catFlag && env.Has("ORBITON_BAT") {
+			batFlag = true
+		}
+		if tailString != "" && !batFlag {
 			fmt.Printf("Copied %d byte%s from %s to the clipboard. Tail bytes: %s\n", n, plural, filename, strings.TrimSpace(strings.ReplaceAll(tailString, "\n", "\\n")))
 		} else {
 			fmt.Printf("Copied %d byte%s from %s to the clipboard.\n", n, plural, filename)
 		}
+		if catFlag {
+			// List the file in a colorful way and quit
+			quitCat(&FilenameOrData{filename, []byte{}, 0, false})
+		} else if batFlag {
+			// List the file in a colorful way, using bat, and quit
+			quitBat(filename)
+		}
+
 		return
 	}
 
@@ -226,7 +249,6 @@ func main() {
 			fmt.Fprintf(os.Stderr, "Could not clear locks: %v\n", lockErr)
 			os.Exit(1)
 		}
-
 		return
 	}
 
@@ -400,6 +422,14 @@ func main() {
 		}
 	}
 
+	if catFlag {
+		// List the file in a colorful way and quit
+		quitCat(&fnord)
+	} else if batFlag { // This should NOT happen if only ORBITON_BAT is set!
+		// List the file in a colorful way, using bat, and quit
+		quitBat(fnord.filename)
+	}
+
 	// Initialize the VT100 terminal
 	tty, err := vt100.NewTTY()
 	if err != nil {
